## File Name: iptw.R
## File version: 1.0

#' Compute inverse probability of treatement weights (IPTW) for use with PCM
#'
#' This function computes IPTW weights for causal inference with the pcm function
#'
#' @param df data.frame containing the data
#' @param Y string containing the name of the column where the dependent variable is stored in df
#' @param X vector of strings containing the names of the columns where the independent variables are stored in df
#' @return A vector of IPT weights
#' @export

iptw <- function(df=NULL,Y=NULL,X=NULL) {
  if (any(!(Y %in% colnames(df)))) {
    stop("ERROR: provided Y variable name does not exist in df")
  }
  if (!("id"%in%colnames(df))) {
    stop('ERROR: no column named id provided')
  }
  dff <- df[,c(Y,X)]
  if (length(X)==1) {
    formu <- paste0(Y,"~",X)
  } else {
    formu <- paste0(Y,"~",X[1])
    for (k in 2:length(X)) {
      xx <- X[k]
      formu <- paste0(formu,"+",xx)
    }
  }
  lr_out <- glm(formula = as.formula(formu),data=df,family = binomial(link = 'logit'))
  psw <- df$TT/fitted(lr_out) + (1-df$TT)/(1-fitted(lr_out))
  return(psw)
}
